==> home-made-io-fastmag-sync-m2-0.19.2-346086.zip: Api/OrderRepositoryInterface.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2020 HOMEMADE.IO SAS
 * @date      2020-09-25
 ******************************************************************************/

namespace Fastmag\Sync\Api;

use Fastmag\Sync\Api\Data\OrderInterface;
use Magento\Framework\Api\SearchCriteriaInterface;

/**
 * Interface OrderRepositoryInterface
 */
interface OrderRepositoryInterface
{
    /**
     * Save order.
     *
     * @param \Fastmag\Sync\Api\Data\OrderInterface $order
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\CouldNotSaveException
     */
    public function save(OrderInterface $order);

    /**
     * Retrieve synchronization.
     *
     * @param int $entityId
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getById($entityId);

    /**
     * Retrieve last synchonization for the specific order id, excluding some transactions types if necessary.
     *
     * @param int      $orderId
     * @param string[] $excludeTypes
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getLastSyncByOrderId(
        $orderId,
        $excludeTypes = [\Fastmag\Sync\Api\Data\Rule\OrdertransactionInterface::FASTMAG_TRANSACTION_TYPE_TRANSFER]
    );

    /**
     * Retrieve orders matching the specified criteria.
     *
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     *
     * @return \Fastmag\Sync\Api\Data\OrderSearchResultsInterface
     */
    public function getList(SearchCriteriaInterface $searchCriteria);

    /**
     * Shortcut method to get all lines applying to a specific order.
     *
     * @param int $orderId
     *
     * @return \Fastmag\Sync\Api\Data\OrderSearchResultsInterface
     */
    public function getListByOrderId($orderId);

    /**
     * Delete order.
     *
     * @param \Fastmag\Sync\Api\Data\OrderInterface $order
     *
     * @return bool true on success
     *
     * @throws \Magento\Framework\Exception\CouldNotDeleteException
     */
    public function delete(OrderInterface $order);

    /**
     * Delete order by ID.
     *
     * @param int $entityId
     *
     * @return bool true on success
     *
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\CouldNotDeleteException
     */
    public function deleteById($entityId);
}

==> home-made-io-fastmag-sync-m2-1.7.3-729356.zip: Api/OrderRepositoryInterface.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2022 HOMEMADE.IO SAS
 * @date      2022-12-02
 ******************************************************************************/

namespace Fastmag\Sync\Api;

use Fastmag\Sync\Api\Data\OrderInterface;
use Magento\Framework\Api\SearchCriteriaInterface;

/**
 * Interface OrderRepositoryInterface
 */
interface OrderRepositoryInterface
{
    /**
     * Save order.
     *
     * @param \Fastmag\Sync\Api\Data\OrderInterface $order
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\CouldNotSaveException
     */
    public function save(OrderInterface $order);

    /**
     * Retrieve synchronization.
     *
     * @param int $entityId
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getById($entityId);

    /**
     * Retrieve last synchonization for the specific order id, excluding some transactions types if necessary.
     *
     * @param int      $orderId
     * @param string[] $excludeTypes
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getLastSyncByOrderId(
        $orderId,
        $excludeTypes = [\Fastmag\Sync\Api\Data\Rule\OrdertransactionInterface::FASTMAG_TRANSACTION_TYPE_TRANSFER]
    );

    /**
     * Retrieve synchronization by Fastmag transaction ID.
     *
     * @param int $transactionId
     *
     * @return \Fastmag\Sync\Api\Data\OrderInterface
     *
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getLastSyncByTransactionId($transactionId);

    /**
     * Retrieve orders matching the specified criteria.
     *
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     *
     * @return \Fastmag\Sync\Api\Data\OrderSearchResultsInterface
     */
    public function getList(SearchCriteriaInterface $searchCriteria);

    /**
     * Shortcut method to get all lines applying to a specific order.
     *
     * @param int $orderId
     *
     * @return \Fastmag\Sync\Api\Data\OrderSearchResultsInterface
     */
    public function getListByOrderId($orderId);

    /**
     * Delete synchronization.
     *
     * @param \Fastmag\Sync\Api\Data\OrderInterface $order
     *
     * @return bool true on success
     *
     * @throws \Magento\Framework\Exception\CouldNotDeleteException
     */
    public function delete(OrderInterface $order);

    /**
     * Delete synchronization by ID.
     *
     * @param int $entityId
     *
     * @return bool true on success
     *
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\CouldNotDeleteException
     */
    public function deleteById($entityId);
}
